Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7066)

Unified Diff: chrome/browser/google_apis/operation_runner.h

Issue 16424004: google_apis: Rename base_operations.h/cc to base_requests.h/cc (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/google_apis/gdata_wapi_service.cc ('k') | chrome/browser/google_apis/operation_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/google_apis/operation_runner.h
diff --git a/chrome/browser/google_apis/operation_runner.h b/chrome/browser/google_apis/operation_runner.h
index 4f5fe3009f97378a14fa518e72d871610b284d97..1d0adb9f98e04bf85bfabd174cc4aa6592c77fe3 100644
--- a/chrome/browser/google_apis/operation_runner.h
+++ b/chrome/browser/google_apis/operation_runner.h
@@ -21,11 +21,11 @@ class URLRequestContextGetter;
namespace google_apis {
-class AuthenticatedOperationInterface;
+class AuthenticatedRequestInterface;
class AuthService;
class OperationRegistry;
// Helper class that runs AuthenticatedOperationInterface objects, handling
// retries and authentication.
class OperationRunner {
public:
@@ -53,21 +53,21 @@ class OperationRunner {
// Cancels all in-flight operations.
void CancelAll();
// Starts an operation implementing the AuthenticatedOperationInterface
// interface, and makes the operation retry upon authentication failures by
// calling back to RetryOperation.
- void StartOperationWithRetry(AuthenticatedOperationInterface* operation);
+ void StartOperationWithRetry(AuthenticatedRequestInterface* operation);
private:
// Called when the access token is fetched.
void OnAccessTokenFetched(
- const base::WeakPtr<AuthenticatedOperationInterface>& operation,
+ const base::WeakPtr<AuthenticatedRequestInterface>& operation,
GDataErrorCode error,
const std::string& access_token);
// Clears any authentication token and retries the operation, which forces
// an authentication token refresh.
- void RetryOperation(AuthenticatedOperationInterface* operation);
+ void RetryOperation(AuthenticatedRequestInterface* operation);
Profile* profile_; // Not owned.
« no previous file with comments | « chrome/browser/google_apis/gdata_wapi_service.cc ('k') | chrome/browser/google_apis/operation_runner.cc » ('j') | no next file with comments »
@@ -21,11 +21,11 @@ class URLRequestContextGetter;
class AuthService;
class OperationRegistry;
-// Helper class that runs AuthenticatedOperationInterface objects, handling
+// Helper class that runs AuthenticatedRequestInterface objects, handling
// retries and authentication.
class OperationRunner {
@@ -53,21 +53,21 @@ class OperationRunner {
// Cancels all in-flight operations.
void CancelAll();
- // Starts an operation implementing the AuthenticatedOperationInterface
+ // Starts an operation implementing the AuthenticatedRequestInterface
// interface, and makes the operation retry upon authentication failures by
// calling back to RetryOperation.

Powered by Google App Engine
This is Rietveld 408576698